@@ -35,8 +35,7 @@ class PPAClsTrainer(object):
         :param configs: 配置字典
         :param use_gpu: 是否使用GPU训练模型
         """
-        if use_gpu:
-            assert (torch.cuda.is_available()), 'GPU不可用'
+        if torch.cuda.is_available():
             self.device = torch.device("cuda")
         else:
             os.environ['CUDA_VISIBLE_DEVICES'] = '-1'
